List of somewhat relevant pyspades forks 
========================================

What was happening with pyspades after development halted? Forks. This is the page to consolidate them

- `<https://github.com/NateShoffner/PySnip/commits/master?after=Y3Vyc29yOtCU%2B4Ixgp7EB1rhkBOVh9rZiwNxKzY5>`_ - the last commit from pyspades, the first commit from pysnip
- `<https://github.com/infogulch/pyspades-events>`_ - event system proposal for pyspades. not compatible with anything, is outdated too. Mirror here: `<https://github.com/Ericson2314/pysnip/tree/evented>`_ (see infogulch:evented for the upstream of that mirror)
- `<https://github.com/Lensman/pysnip>`_ - a google code mirror, with basicbot.py added (proof `<https://github.com/infogulch/pyspades/compare/BnS...iamgreaser:lensman?diff=split&name=lensman&w=1>`_
- `<https://github.com/cmr/pyspades>`_ - a mirror without any new commits
- `<https://bitbucket.org/mari_kiri/pyckaxe/>`_ - not pyspades, but someone's else implementation of AoS protocol
- `<https://github.com/10se1ucgo/PySnip1.0>`_ - aos 1.0 implementation on top of pysnip
- `<https://github.com/infogulch/pyspades>`_ - the main source of extra contribution
- `<https://github.com/Ericson2314/pysnip>`_ - some extra interesting additions here and there, mostly cosmetic?
- `<https://github.com/iamgreaser/pysnip/compare/BnS...iamgreaser:minit>`_ - changes of the minit.nu server. A lot of changes with cryptic history.
- `<https://github.com/infogulch/pyspades/pull/290>`_ - essentially discontinued powerthirst
- `<https://github.com/infogulch/pyspades/compare/BnS...iamgreaser:BnS?w=1>`_ - the boiled down powerthirst shebang 

.. note:: 

   iamgreaser's BnS branch includes some extra powerthirst changes. The 'prestine' (kinda) BnS branch is only infogulch's one

things worth checking: bots from infogulch
